@@ -1,6 +1,6 @@
 /*
 
- $Id: shellOutputDlg.h,v 1.5 2001/02/23 18:46:10 mjarrett Exp $
+ $Id: shellOutputDlg.h,v 1.10 2004/05/26 10:38:08 pinto Exp $
 
  ark -- archiver for the KDE project
 
@@ -21,34 +21,27 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
 #ifndef SHELL_OUTPUT_DLG_H
 #define SHELL_OUTPUT_DLG_H
 
-#include <qmultilineedit.h>
-#include <qdialog.h>
+#include <kdialogbase.h>
 
 class QWidget;
+class QString;
+class QTextEdit;
 
-class ArkSettings;
-
-class ShellOutputWidget : public QMultiLineEdit {
-public:
-  ShellOutputWidget( QDialog* _d ) : QMultiLineEdit( _d ) 
-    { setNumCols(80); };
-};
-
-
-
-class ShellOutputDlg : public QDialog 
+class ShellOutputDlg : public KDialogBase
 {
-  Q_OBJECT
-public:
-  ShellOutputDlg( ArkSettings *, QWidget *parent=0, const char *name=0 );
-  
+	Q_OBJECT
+	public:
+		ShellOutputDlg( const QString& text, QWidget *parent=0, const char *name=0 );
+		~ShellOutputDlg();
+	private:
+		QTextEdit * m_outputViewer;
 };
 
 #endif /* SHELL_OUTPUT_DLG_H */
