@@ -1,6 +1,6 @@
   /*
 
-    $Id: kedit.cpp,v 1.195 2003/11/20 14:09:52 waba Exp $
+    $Id: kedit.cpp,v 1.203 2004/07/13 20:23:31 bmeyer Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -38,14 +38,13 @@
 #include <kconfigdialog.h>
 #include <kcursor.h>
 #include <keditcl.h>
-#include <kedittoolbar.h>
 #include <kfileitem.h>
 #include <kfontdialog.h>
 #include <kio/netaccess.h>
-#include <kkeydialog.h>
 #include <kmessagebox.h>
 #include <kprinter.h>
 #include <ksavefile.h>
+#include <kstdguiitem.h>
 #include <kstatusbar.h>
 #include <kspell.h>
 #include <kurldrag.h>
@@ -67,7 +66,6 @@ TopLevel::TopLevel (QWidget *, const char *name)
   : KMainWindow ( 0,name ), kspellconfigOptions(0),
   eframe(0), newWindow(false), kspell(0)
 {
-  setAutoSaveSettings();
   if (!windowList)
   {
      windowList = new QPtrList<TopLevel>;
@@ -80,15 +78,17 @@ TopLevel::TopLevel (QWidget *, const char *name)
 
   connect(kapp,SIGNAL(kdisplayPaletteChanged()),this,SLOT(set_colors()));
 
+  resize(550,400); // Default size
+
   setupStatusBar();
   setupActions();
 
-  resize(550,400); // Default size
-
   readSettings();
 
   setupEditWidget();
 
+  setupGUI();
+
   setAcceptDrops(true);
 
   setFileCaption();
@@ -168,9 +168,9 @@ void TopLevel::setupEditWidget()
 
   right_mouse_button->insertItem (i18n("Open..."),
 				  this, 	SLOT(file_open()));
-  right_mouse_button->insertItem (i18n("Save"),
+  right_mouse_button->insertItem (SmallIcon("filesave"),i18n("Save"),
 				  this, 	SLOT(file_save()));
-  right_mouse_button->insertItem (i18n("Save As..."),
+  right_mouse_button->insertItem (SmallIcon("filesaveas"),i18n("Save As..."),
 				  this, SLOT(file_save_as()));
   right_mouse_button->insertSeparator(-1);
   right_mouse_button->insertItem(i18n("Copy"),
@@ -232,16 +232,7 @@ void TopLevel::setupActions()
     // setup Go menu
     KStdAction::gotoLine(this, SLOT(gotoLine()), actionCollection());
 
-    // setup Settings menu
-    createStandardStatusBarAction();
-    setStandardToolBarMenuEnabled(true);
-
     KStdAction::preferences(this, SLOT(showSettings()), actionCollection());
-
-    KStdAction::keyBindings(this, SLOT(editKeys()), actionCollection());
-    KStdAction::configureToolbars(this, SLOT(editToolbars()), actionCollection());
-
-    createGUI();
 }
 
 void TopLevel::setupStatusBar()
@@ -441,11 +432,11 @@ void TopLevel::spell_done(const QString& newtext)
   if (kspell->dlgResult() == 0)
   {
      eframe->setText( newtext);
-     statusBar()->changeItem (i18n("Spellcheck:  Aborted"), ID_GENERAL);
+     statusBar()->changeItem (i18n("Spellcheck:  Aborted."), ID_GENERAL);
   }
   else
   {
-     statusBar()->changeItem (i18n("Spellcheck:  Complete"), ID_GENERAL);
+     statusBar()->changeItem (i18n("Spellcheck:  Complete."), ID_GENERAL);
   }
   kspell->cleanUp();
 }
@@ -463,7 +454,7 @@ void TopLevel::spell_finished( )
   else if (status == KSpell::Crashed)
   {
      eframe->spellcheck_stop();
-     statusBar()->changeItem (i18n("Spellcheck:  Crashed"), ID_GENERAL);
+     statusBar()->changeItem (i18n("Spellcheck:  Crashed."), ID_GENERAL);
      KMessageBox::sorry(this, i18n("ISpell seems to have crashed."));
   }
 }
@@ -490,7 +481,7 @@ void TopLevel::file_open( void )
                          i18n("The file you have requested is larger than KEdit is designed for. "
                               "Please ensure you have enough system resources available to safely load this file, "
                               "or consider using a program that is designed to handle large files such as KWrite."),
-                        i18n("Attempting To Open Large File"),
+                        i18n("Attempting to Open Large File"),
                         KStdGuiItem::cont(), "attemptingToOpenLargeFile") == KMessageBox::Cancel)
     {
         return;
@@ -546,7 +537,7 @@ void TopLevel::file_insert()
   {
     KURL url = KTextFileDialog::getOpenURLwithEncoding(
         QString::null, QString::null, this,
-	i18n("Insert File") );
+	i18n("Insert File"), "", KStdGuiItem::insert().text());
     if( url.isEmpty() )
     {
       return;
@@ -828,7 +819,7 @@ void TopLevel::showSettings()
 
   initSpellConfig();
   KConfigDialog* dialog = new SettingsDialog(this, "settings", Prefs::self(), kspellconfigOptions);
-  
+
   connect(dialog, SIGNAL(settingsChanged()), this, SLOT(updateSettings()));
   dialog->show();
 }
@@ -839,35 +830,12 @@ void TopLevel::initSpellConfig()
      kspellconfigOptions = new KSpellConfig(0 , "SpellingSettings", 0, false );
 }
 
-void TopLevel::editKeys()
-{
-  KKeyDialog::configure(actionCollection());
-}
-
-
-void TopLevel::editToolbars()
-{
-  saveMainWindowSettings(KGlobal::config(), "MainWindow");
-  KEditToolbar dlg(actionCollection());
-  connect(&dlg, SIGNAL( newToolbarConfig() ), this, SLOT( slotNewToolbarConfig() ));
-  dlg.exec();
-}
-
-
-void TopLevel::slotNewToolbarConfig()
-{
-  createGUI();
-  applyMainWindowSettings(KGlobal::config(), "MainWindow");
-}
-
-
 void TopLevel::search_again()
 {
   eframe->repeatSearch();
   statusbar_slot();
 }
 
-
 void TopLevel::setFileCaption()
 {
   if (m_url.isEmpty())
@@ -1160,7 +1128,7 @@ void TopLevel::openURL( const KURL& _url, int _mode )
     {
       if (_mode & OPEN_NEW == 0)
       {
-         KMessageBox::error(this, i18n("Cannot download file!"));
+         KMessageBox::error(this, i18n("Cannot download file."));
          return;
       }
     }
@@ -1269,12 +1237,12 @@ void TopLevel::toggle_overwrite(){
 
 }
 
-static const char description[] = I18N_NOOP("A KDE Text Editor");
+static const char description[] = I18N_NOOP("KDE text editor");
 
 static const KCmdLineOptions options[] =
 {
 	{ "encoding <encoding>", I18N_NOOP("Encoding to use for the following documents"), 0 },
-	{ "+file", I18N_NOOP("File or URL to Open"), 0 },
+	{ "+file", I18N_NOOP("File or URL to open"), 0 },
 	KCmdLineLastOption
 };
 
@@ -1352,10 +1320,10 @@ SettingsDialog::SettingsDialog(QWidget *parent, const char *name,KConfigSkeleton
   addPage(color, i18n("Color"), "colorize", i18n("Text Color in Editor Area"));
 
   // Spelling
-  addPage(spellConfig, i18n("Spelling"), 
+  addPage(spellConfig, i18n("Spelling"),
   	  "spellcheck", i18n("Spelling Checker"));
   connect(spellConfig, SIGNAL(configChanged()), this, SLOT(slotSpellConfigChanged()));
- 
+
   // Miscellaneous
   Misc *miscOptions = new Misc(0, "MiscSettings");
   addPage(miscOptions, i18n("Miscellaneous"), "misc");
