@@ -680,7 +680,7 @@ CReplacePromptDialog::CReplacePromptDialog( QWidget *parent, const char *name,
 					     bool modal )
   :KDialogBase( Plain, i18n("Find & Replace"), User3|User2|User1|Close,
 		User2, parent, name, modal, true, i18n("&All"),
-		KStdGuiItem::no().text(), KStdGuiItem::yes().text() )
+		KStdGuiItem::no(), KStdGuiItem::yes() )
 {
   QString text;
   QBoxLayout *topLayout = new QVBoxLayout( plainPage(), 0, spacingHint() );
@@ -1070,6 +1070,7 @@ CInsertDialog::CInsertDialog( QWidget *parent, const char *name, bool modal )
   :KDialogBase( Plain, i18n("Insert Pattern"), Ok|Cancel, Ok,
 		parent, name, modal )
 {
+  setButtonOKText(i18n("&Insert"));
 
   QString text;
   QVBoxLayout *topLayout = new QVBoxLayout( plainPage(), 0, spacingHint() );
