@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -25,19 +25,19 @@
 #include <config.h>
 #endif 
 
-#include <iostream.h>
+#include <iostream>
 #include <time.h>
 
 #include <qbitarray.h> 
 #include <qdatetime.h> 
 #include <qfile.h>
 #include <qfont.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qpainter.h>
 #include <qstring.h>
 #include <qtextstream.h>
 
-#include "kapp.h"
+#include <kapplication.h>
 
 #include "conversion.h"
 #include "hexeditstate.h"
@@ -170,12 +170,12 @@ struct SStatisticControl
 {
   SStatisticControl( void )
   {
-    memset( occurence, 0, sizeof(occurence) );
+    memset( occurrence, 0, sizeof(occurrence) );
     documentSize = 0;
   }
 
   uint documentSize;
-  uint occurence[256];
+  uint occurrence[256];
   QString documentName;
 };
 
@@ -276,7 +276,7 @@ class CStringCollectControl
       return( mList.count() );
     }
 
-    QList<QString> &list( void )
+    QPtrList<QString> &list( void )
     {
       return( mList );
     }
@@ -287,7 +287,7 @@ class CStringCollectControl
     bool allow8bit;
 
   private:
-    QList<QString> mList;
+    QPtrList<QString> mList;
 };
 
 
@@ -432,8 +432,8 @@ struct SCursorSpec
 
   void dump( void )
   {
-    cout << "offset: " << offset << " y: " << y << " x1: " << x1 << endl;
-    cout << "x2: " << x2 << " cell: " << cell << endl;
+    std::cout << "offset: " << offset << " y: " << y << " x1: " << x1 << std::endl;
+    std::cout << "x2: " << x2 << " cell: " << cell << std::endl;
   }
 
   bool inside( uint min, uint max )
@@ -1159,12 +1159,13 @@ class CHexBuffer : public QByteArray
     inline const SDisplayLayout &layout( void );
 
     inline const SDisplayInputMode &inputMode( void );
-    inline QList<SCursorOffset> &bookmarkList( void );
+    inline QPtrList<SCursorOffset> &bookmarkList( void );
 
     inline bool documentPresent( void );
     inline bool modified( void );
     inline uint undoState( void );
     inline uint documentSize( void );
+    inline void setModified( bool modified );
     inline EEditMode editMode( void );
     inline const SEncodeState &encoding( void );
     inline bool losslessEncoding( CConversion::EMode mode );
@@ -1303,7 +1304,7 @@ class CHexBuffer : public QByteArray
     CConversion mEncode;
     bool mCharValid[256];
 
-    char *mColorIndex;
+    unsigned char *mColorIndex;
     char *mPrintBuf;
     bool mLoadingData;
     int  mStartX;
@@ -1348,8 +1349,8 @@ class CHexBuffer : public QByteArray
 
     uint mUndoLimit;
     uint mUndoIndex;
-    QList<CHexActionGroup> mUndoList;
-    QList<SCursorOffset> mBookmarkList;
+    QPtrList<CHexActionGroup> mUndoList;
+    QPtrList<SCursorOffset> mBookmarkList;
     QBitArray mBookmarkMap;
 
     PrintCellFunc   printCell;
@@ -1428,7 +1429,7 @@ inline const SDisplayInputMode &CHexBuffer::inputMode( void )
   return( mInputMode );
 }
 
-inline QList<SCursorOffset> &CHexBuffer::bookmarkList( void )
+inline QPtrList<SCursorOffset> &CHexBuffer::bookmarkList( void )
 {
   return( mBookmarkList );
 }
@@ -1467,6 +1468,11 @@ inline bool CHexBuffer::modified( void )
   return( mDocumentModified );
 }
 
+inline void CHexBuffer::setModified( bool modified )
+{
+  mDocumentModified = modified;
+}
+
 inline uint CHexBuffer::undoState( void )
 {
   return( (mUndoIndex > 0 ? UndoOk : 0) | 
