@@ -17,29 +17,32 @@
  * along with this library; see the file COPYING.LIB.  If not, write to
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
- */ 
+ */
 
 
 
 #include <qtabwidget.h>
 #include <qlayout.h>
 #include <qtimer.h>
-#include <qpushbutton.h>
 #include <kstatusbar.h>
 #include <klocale.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 #include "kpcmcia.h"
 
 #include "kpcmciainfo.h"
 
 
-KPCMCIAInfo::KPCMCIAInfo(KPCMCIA *pcmcia, QWidget *parent, const char *name) 
+KPCMCIAInfo::KPCMCIAInfo(KPCMCIA *pcmcia, QWidget *parent, const char *name)
   : KDialog(parent, name, false), _pcmcia(pcmcia) {
 
   setMinimumSize(300,400);
 
   _mainGrid = new QGridLayout(this, 9, 5);
-  
+
   _mainTab = new QTabWidget(this);
   _mainGrid->addMultiCellWidget(_mainTab, 0, 6, 0, 4);
   _mainGrid->setRowStretch(0, 1);
@@ -68,7 +71,7 @@ KPCMCIAInfo::KPCMCIAInfo(KPCMCIA *pcmcia, QWidget *parent, const char *name)
   _updateButton = new QPushButton(i18n("&Update"), this);
   _mainGrid->addWidget(_updateButton, 7, 3);
   connect(_updateButton, SIGNAL(pressed()), this, SLOT(update()));
-  _closeButton = new QPushButton(i18n("&Close"), this);
+  _closeButton = new KPushButton(KStdGuiItem::close(), this);
   _mainGrid->addWidget(_closeButton, 7, 4);
   connect(_closeButton, SIGNAL(pressed()), this, SLOT(slotClose()));
   _mainGrid->setRowStretch(7, 0);
